@@ -1,5 +1,7 @@
 from django.http import HttpResponse
-import simplejson as json
+
+from ajaxtoolkit.jsonwrapper import json
+
 
 class JsonResponse(HttpResponse):
     def __init__(self, dict_content=None, mimetype='application/json', status=None, content_type=None):
